# hs110-exporter
Prometheus exporter for tp-link hs110

## Overview
The project is currently WIP.
The hs110-exporter allows to retrieve status and energy information from tp-link HS110.
The project uses parts of the tp-link HS110 code from https://github.com/softScheck/tplink-smartplug.git.
The exporter is based on the python-exporter code form smpt-exporter https://github.com/prometheus/snmp_exporter.git
in early stages.
